pain
====

Lein for Python... manage various project scaffoldings and settings.

Does not include more than the basic scaffolding as of yet, early days here.

Installation
-----

```python
pip install pain
```

Usage
------
```python
pain new app_name
```

Contribute!
-----------
* Add more file templates
* Add more project scaffolds
* Implement the config file specification :)